@@ -14,6 +14,7 @@
 
 """Run isort to check if Python import definitions are sorted."""
 
+import os
 import subprocess
 import sys
 import unittest
@@ -28,16 +29,13 @@ class IsortTestCase(unittest.TestCase):
     is provided by the get_source_files() function.
     """
 
-    def test_isort(self):
+    @unittest.skipIf(os.environ.get("SKIP_LINTERS"), "requested via SKIP_LINTERS env variable")
+    def test_isort(self) -> None:
         """Test: Run isort on Python source code."""
-
-        cmd = ["isort", "--check-only", "--diff", "-l", "99"] + get_source_files()
+        cmd = ["isort", "--check-only", "--diff"] + get_source_files()
         if unittest_verbosity() >= 2:
             sys.stderr.write(f"Running following command:\n{' '.join(cmd)}\n")
-        with subprocess.Popen(
-            cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, close_fds=True
-        ) as process:
-            output = process.communicate()[0].decode()
+        process = subprocess.run(cmd, capture_output=True, check=False, text=True)
 
         if process.returncode != 0:  # pragma: no cover
-            self.fail(f"isort found unsorted Python import definitions:\n{output.strip()}")
+            self.fail(f"isort found unsorted Python import definitions:\n{process.stdout.strip()}")
