@@ -14,6 +14,7 @@
 
 """Run shellcheck on Shell code."""
 
+import os
 import subprocess
 import sys
 import unittest
@@ -29,7 +30,8 @@ class ShellcheckTestCase(unittest.TestCase):
     on Shell source code.
     """
 
-    def test_flake8(self):
+    @unittest.skipIf(os.environ.get("SKIP_LINTERS"), "requested via SKIP_LINTERS env variable")
+    def test_shellcheck(self) -> None:
         """Test: Run shellcheck on Shell source code."""
         cmd = ["shellcheck"] + [get_path(s) for s in SHELL_SCRIPTS]
         if unittest_verbosity() >= 2:
